translate.misc.selector.EnvironDispatcher

Package translate :: Package misc :: Module selector :: Class EnvironDispatcher |
[hide private]
[frames] | no frames]

# Class EnvironDispatcher

source code

Dispatch based on list of rules.

Instance Methods | [hide private]
__init__(self, rules) Instantiate with a list of (predicate, wsgiapp) rules. | source code
__call__(self, environ, start_response) Call the first app whose predicate is true. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, rules) (Constructor) | source code
Instantiate with a list of (predicate, wsgiapp) rules. Overrides: object.__init__

### __call__(self, environ, start_response) (Call operator) | source code
Call the first app whose predicate is true. Each predicate is passes the environ to evaluate.